
.restloadingDiv {
background:url("/static/ajax-loader.gif") no-repeat center center;
background-color: transparent;
height: 100px;
width: 100px;
position: relative;
/*left: 50%;*/
/*top: 50%;*/
/*margin: -25px 0 0 -25px;*/
z-index: 1000;
display: block;
margin-left: auto;
margin-right: auto;
}

.horizLayoutR {

    display: inline-block;
    height:500px;
    float:right;
    width:50%;
    overflow-y:auto;

}

.horizLayoutL {

    display: inline-block;
    height:500px;
    float:left;
    width:50%;

}

.restapiholder {
    background-color: #DDDDDD !important;
    border: 1px solid #DDDDDD !important;
    border-radius: 4px 4px 4px 4px;
    margin: 15px 0 !important;
    /*position: relative !important;*/
}

.restapiholdermethod {
     background-color: #FFFFFF !important;
    border: 1px solid #DDDDDD !important;
    border-radius: 4px 4px 4px 4px;
    margin: 15px 0 !important;
    padding: 39px 19px 14px !important;
    /*position: relative !important;*/
    display: inline-block !important;
    float:left !important;
    width:40% !important;
}

.restapiholderresponse {
    background-color: #FFFFFF !important;
    border: 1px solid #DDDDDD !important;
    border-radius: 4px 4px 4px 4px;
    margin: 15px 0 !important;
    padding: 5px 5px 5px 5px;
    position: relative !important;
    display: inline-block !important;
    float:right !important;
    width:50% !important;
    /*max-height: 700px;*/
    height:inherit;

}

.restsuccess {

    border: 3px solid #468847 !important;

}


.resterror {

    background-color: #F2DEDE;
    border: 3px solid #B94A48 !important;

}

.well {

    word-wrap: break-word;

}

.mhsy {

    max-height: 80px;
    overflow-y: auto;

}

textarea {
width:97%;
}

.drop_zone {
    border: 2px dashed rgb(187, 187, 187);
    border-radius: 5px 5px 5px 5px;
    padding: 5px;
    text-align: center;
    font: 20pt bold,"Vollkorn";
    min-height: 50px;
}

.clipboardBtn, .clipboardStatus {
    font-size: 60%;
}

.clipboardStatus {
    padding-left: 0.5em;
}

a {
   outline: 0;
}

object, embed {
  outline: 0;
}
